import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_codecommit._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-pull-request-approval-rule",
    "1.0.34",
    __name__[0:-6],
    "cdk-pull-request-approval-rule@1.0.34.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
